@@ -6,6 +6,7 @@ import os
 import traceback
 import unittest
 from functools import partial, wraps
+from typing import Any, Dict, TYPE_CHECKING
 
 import requests
 from gxformat2 import (
@@ -21,7 +22,8 @@ from galaxy.selenium.context import (
     GalaxySeleniumContext,
 )
 from galaxy.selenium.navigates_galaxy import (
-    retry_during_transitions
+    NavigatesGalaxy,
+    retry_during_transitions,
 )
 from galaxy.util import (
     asbool,
@@ -36,7 +38,7 @@ from galaxy_test.base.testcase import FunctionalTestCase
 try:
     from galaxy_test.driver.driver_util import GalaxyTestDriver
 except ImportError:
-    GalaxyTestDriver = None  # type: ignore
+    GalaxyTestDriver = None  # type: ignore[misc,assignment]
 
 DEFAULT_TIMEOUT_MULTIPLIER = 1
 DEFAULT_TEST_ERRORS_DIRECTORY = os.path.abspath("database/test_errors")
@@ -49,7 +51,7 @@ DEFAULT_DOWNLOAD_PATH = driver_factory.DEFAULT_DOWNLOAD_PATH
 TIMEOUT_MULTIPLIER = float(os.environ.get("GALAXY_TEST_TIMEOUT_MULTIPLIER", DEFAULT_TIMEOUT_MULTIPLIER))
 GALAXY_TEST_ERRORS_DIRECTORY = os.environ.get("GALAXY_TEST_ERRORS_DIRECTORY", DEFAULT_TEST_ERRORS_DIRECTORY)
 GALAXY_TEST_SCREENSHOTS_DIRECTORY = os.environ.get("GALAXY_TEST_SCREENSHOTS_DIRECTORY", None)
-# Test browser can be ["CHROME", "FIREFOX", "OPERA", "PHANTOMJS"]
+# Test browser can be ["CHROME", "FIREFOX", "OPERA"]
 GALAXY_TEST_SELENIUM_BROWSER = os.environ.get("GALAXY_TEST_SELENIUM_BROWSER", driver_factory.DEFAULT_SELENIUM_BROWSER)
 GALAXY_TEST_SELENIUM_REMOTE = os.environ.get("GALAXY_TEST_SELENIUM_REMOTE", driver_factory.DEFAULT_SELENIUM_REMOTE)
 GALAXY_TEST_SELENIUM_REMOTE_PORT = os.environ.get("GALAXY_TEST_SELENIUM_REMOTE_PORT", driver_factory.DEFAULT_SELENIUM_REMOTE_PORT)
@@ -128,8 +130,9 @@ def dump_test_information(self, name_prefix):
             write_file("page_source.txt", self.driver.page_source)
             write_file("DOM.txt", self.driver.execute_script("return document.documentElement.outerHTML"))
         except Exception:
-            print("Failed to use test driver to recover debug information from Selenium.")
-            write_file("selenium_exception.txt", traceback.format_exc())
+            formatted_exception = traceback.format_exc()
+            print(f"Failed to use test driver to recover debug information from Selenium: {formatted_exception}")
+            write_file("selenium_exception.txt", formatted_exception)
 
         for log_type in ["browser", "driver"]:
             try:
@@ -384,6 +387,20 @@ class TestWithSeleniumMixin(GalaxyTestSeleniumContext, UsesApiTestCaseMixin):
             self.assert_no_error_message()
         return GALAXY_TEST_SELENIUM_ADMIN_USER_EMAIL
 
+    @retry_assertion_during_transitions
+    def assert_workflow_has_changes_and_save(self):
+        save_button = self.components.workflow_editor.save_button
+        save_button.wait_for_visible()
+        assert not save_button.has_class("disabled")
+        save_button.wait_for_and_click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+
+    @retry_assertion_during_transitions
+    def assert_modal_has_text(self, expected_text):
+        modal_element = self.components.workflow_editor.state_modal_body.wait_for_visible()
+        text = modal_element.text
+        assert expected_text in text, f"Failed to find expected text [{expected_text}] in modal text [{text}]"
+
     def workflow_upload_yaml_with_random_name(self, content, **kwds):
         workflow_populator = self.workflow_populator
         name = self._get_random_name()
@@ -455,17 +472,24 @@ class SharedStateSeleniumTestCase(SeleniumTestCase):
         """Override this to setup shared data for tests that gets initialized only once."""
 
 
-class UsesLibraryAssertions:
+if TYPE_CHECKING:
+    NavigatesGalaxyMixin = NavigatesGalaxy
+else:
+    NavigatesGalaxyMixin = object
+
+
+class UsesLibraryAssertions(NavigatesGalaxyMixin):
 
     @retry_assertion_during_transitions
     def assert_num_displayed_items_is(self, n):
-        self.assertEqual(n, self.num_displayed_items())
+        num_displayed = self.num_displayed_items()
+        assert n == num_displayed, f"Expected number of displayed items is {n} but actual was {num_displayed}"
 
-    def num_displayed_items(self):
+    def num_displayed_items(self) -> int:
         return len(self.libraries_table_elements())
 
 
-class UsesHistoryItemAssertions:
+class UsesHistoryItemAssertions(NavigatesGalaxyMixin):
 
     def assert_item_peek_includes(self, hid, expected):
         item_body = self.history_panel_item_component(hid=hid)
@@ -580,7 +604,8 @@ class SeleniumSessionGetPostMixin:
             full_url = f"{full_url}?key={self._mixin_admin_api_key}"
         else:
             cookies = self.selenium_context.selenium_to_requests_cookies()
-        response = requests.post(full_url, data=data, cookies=cookies, files=files, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT)
+        request_kwd = self._prepare_request_data(dict(cookies=cookies, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT, files=files), data, as_json=json)
+        response = requests.post(full_url, **request_kwd)
         return response
 
     def _delete(self, route, data=None, headers=None, admin=False, json: bool = False) -> Response:
@@ -591,7 +616,8 @@ class SeleniumSessionGetPostMixin:
             full_url = f"{full_url}?key={self._mixin_admin_api_key}"
         else:
             cookies = self.selenium_context.selenium_to_requests_cookies()
-        response = requests.delete(full_url, data=data, cookies=cookies, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT)
+        request_kwd = self._prepare_request_data(dict(cookies=cookies, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT), data, as_json=json)
+        response = requests.delete(full_url, **request_kwd)
         return response
 
     def _put(self, route, data=None, headers=None, admin=False, json: bool = False) -> Response:
@@ -602,9 +628,17 @@ class SeleniumSessionGetPostMixin:
             full_url = f"{full_url}?key={self._mixin_admin_api_key}"
         else:
             cookies = self.selenium_context.selenium_to_requests_cookies()
-        response = requests.put(full_url, data=data, cookies=cookies, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT)
+        request_kwd = self._prepare_request_data(dict(cookies=cookies, headers=headers, timeout=DEFAULT_SOCKET_TIMEOUT), data, as_json=json)
+        response = requests.put(full_url, **request_kwd)
         return response
 
+    def _prepare_request_data(self, request_kwd: Dict[str, Any], data: Dict[str, Any], as_json: bool = False):
+        if as_json:
+            request_kwd['json'] = data
+        else:
+            request_kwd['data'] = data
+        return request_kwd
+
 
 class SeleniumSessionDatasetPopulator(SeleniumSessionGetPostMixin, populators.BaseDatasetPopulator):
 
@@ -625,7 +659,7 @@ class SeleniumSessionDatasetCollectionPopulator(SeleniumSessionGetPostMixin, pop
         self.dataset_populator = SeleniumSessionDatasetPopulator(selenium_context)
 
     def _create_collection(self, payload: dict) -> Response:
-        create_response = self._post("dataset_collections", data=payload)
+        create_response = self._post("dataset_collections", data=payload, json=True)
         return create_response
 
 
@@ -637,7 +671,7 @@ class SeleniumSessionWorkflowPopulator(SeleniumSessionGetPostMixin, populators.B
         """Construct a workflow populator from a bioblend GalaxyInstance."""
         self.selenium_context = selenium_context
         self.dataset_populator = SeleniumSessionDatasetPopulator(selenium_context)
-        self.dataset_collection_populator = SeleniumSessionDatasetPopulator(selenium_context)
+        self.dataset_collection_populator = SeleniumSessionDatasetCollectionPopulator(selenium_context)
 
     def import_workflow(self, workflow: dict, **kwds) -> dict:
         workflow_str = json.dumps(workflow, indent=4)
