@@ -9,6 +9,33 @@ class AdminAppTestCase(SeleniumTestCase):
 
     requires_admin = True
 
+    @selenium_test
+    def test_html_allowlist(self):
+        admin_component = self.components.admin
+        self.admin_login()
+        self.admin_open()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_landing')
+        admin_component.index.allowlist.wait_for_and_click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_allowlist_landing')
+        admin_component.allowlist.local.wait_for_and_click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_allowlist_local_landing')
+        # This should be updated if the list of built-in converters is changed.
+        render_button = self.driver.find_element_by_xpath("//td[.='CONVERTER_bam_to_bigwig_0']/following::td/button")
+        render_button.click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_allowlist_converter_html_rendered')
+        admin_component.allowlist.rendered_active.wait_for_and_click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_allowlist_render_landing')
+        self.sleep_for(self.wait_types.UX_RENDER)
+        sanitize_button = self.driver.find_element_by_xpath("//td[.='CONVERTER_bam_to_bigwig_0']/following::td/button")
+        sanitize_button.click()
+        self.sleep_for(self.wait_types.UX_RENDER)
+        self.screenshot('admin_allowlist_converter_sanitized')
+
     @selenium_test
     @flakey
     def test_admin_toolshed(self):
@@ -184,10 +211,11 @@ class AdminAppTestCase(SeleniumTestCase):
         self.screenshot("admin_data_manager")
 
         with self.dataset_populator.test_history() as history_id:
-            run_response = self.dataset_populator.run_tool(tool_id="data_manager",
-                                                           inputs={"ignored_value": "test"},
-                                                           history_id=history_id,
-                                                           assert_ok=False)
+            run_response = self.dataset_populator.run_tool_raw(
+                tool_id="data_manager",
+                inputs={"ignored_value": "test"},
+                history_id=history_id,
+            )
             job_id = run_response.json()["jobs"][0]["id"]
             self.dataset_populator.wait_for_tool_run(history_id=history_id,
                                                      run_response=run_response,
