@@ -49,7 +49,7 @@ class ManageInformationTestCase(SeleniumTestCase):
         new_email = self._get_random_email()
         # new email should be different from initially registered
         self.assertTrue(email != new_email)
-        email_input_field = self.driver.find_element_by_css_selector("[tour_id='email'] input")
+        email_input_field = self.driver.find_element_by_css_selector("input[id='email']")
 
         self.clear_input_field_and_write(email_input_field, new_email)
         self.components.change_user_email.submit.wait_for_and_click()
@@ -63,7 +63,7 @@ class ManageInformationTestCase(SeleniumTestCase):
     @selenium_test
     def test_public_name(self):
         def get_name_input_field():
-            return self.driver.find_element_by_css_selector("[tour_id='username'] input")
+            return self.driver.find_element_by_css_selector("input[id='username']")
 
         def assert_public_name(expected_name):
             self.assertTrue(expected_name == get_name_input_field().get_attribute('value'))
