@@ -121,7 +121,7 @@ class HistoryGridTestCase(SharedStateSeleniumTestCase):
     @retry_assertion_during_transitions
     def assert_grid_histories_sorted_by_owner(self):
         histories = self.get_histories()
-        index_1, index_2, index_3 = [histories.index(n) for n in self.all_histories]
+        index_1, index_2, index_3 = (histories.index(n) for n in self.all_histories)
         # 1 and 3 are owned by a owner whose username lexicographically
         # precedes 2. So verify 1 and 3 come before 2.
         assert index_1 < index_2
