@@ -188,6 +188,32 @@ steps:
         content = self.dataset_populator.get_history_dataset_content(history_id, hid=7)
         self.assertEqual("10.0\n30.0\n20.0\n40.0\n", content)
 
+    @selenium_test
+    @managed_history
+    def test_execution_with_text_default_value_connected_to_restricted_select(self):
+        self.open_in_workflow_run("""
+class: GalaxyWorkflow
+inputs:
+  text_param:
+    optional: true
+    default: ex2
+    restrictOnConnections: true
+    type: text
+steps:
+  multi_select:
+    tool_id: multi_select
+    in:
+      select_ex:
+        source: text_param
+""")
+        element = self.components.workflow_run.input_select_field(label="text_param").wait_for_present()
+        assert element.text == 'Ex2'
+        self.workflow_run_submit()
+        history_id = self.current_history_id()
+        self.workflow_populator.wait_for_history_workflows(history_id, expected_invocation_count=1)
+        content = self.dataset_populator.get_history_dataset_content(history_id, hid=1)
+        assert content == 'ex2'
+
     @selenium_test
     @managed_history
     def test_execution_with_rules(self):
@@ -212,12 +238,9 @@ steps:
         self.open_in_workflow_run(WORKFLOW_WITH_CUSTOM_REPORT_1)
         self.workflow_run_specify_inputs(inputs)
         self.workflow_run_submit()
-
         self.sleep_for(self.wait_types.UX_TRANSITION)
         self.screenshot("workflow_run_invocation_report")
-
         self.workflow_populator.wait_for_history_workflows(history_id, expected_invocation_count=1)
-
         invocation_0 = self.workflow_populator.history_invocations(history_id)[0]
         self.get(f"workflows/invocations/report?id={invocation_0['id']}")
         self.wait_for_selector_visible(".embedded-dataset")
@@ -266,9 +289,9 @@ steps:
         content = self.dataset_populator.get_history_dataset_content(history_id, hid=hid)
         assert len([x for x in content.split("\n") if x]) == 3, content
 
-    def _set_num_lines_to_3(self, tour_id):
+    def _set_num_lines_to_3(self, element_id):
         # for random_lines num_lines parameter as runtime parameter in workflow form.
-        div = self.tool_parameter_div(tour_id)
+        div = self.tool_parameter_div(element_id)
         input_element = div.find_element_by_css_selector("input")
         # runtime parameters not being set to tool default value:
         # https://github.com/galaxyproject/galaxy/pull/7157
@@ -277,9 +300,9 @@ steps:
         input_element.clear()
         input_element.send_keys("3")
 
-    def _set_replacement_parameter(self, tour_id, value):
+    def _set_replacement_parameter(self, element_id, value):
         # for random_lines num_lines parameter as runtime parameter in workflow form.
-        div = self.tool_parameter_div(tour_id)
+        div = self.tool_parameter_div(element_id)
         input_element = div.find_element_by_css_selector("input")
         initial_value = input_element.get_attribute("value")
         assert initial_value == "", initial_value
